@@ -209,10 +209,12 @@ if ($do==1) {
       '__display__');
    ($stdout,$stderr)=$handle->cmd("perl -e \'use CPAN;".
       "CPAN::HandleConfig-\>load;print \$CPAN::Config-\>{build_dir}\'");
+print "STDOUT for BUILDDIR=$stdout and STDERR FOR PERL=$stderr\n";sleep 20;
    my $builddir=$stdout;
    my $fa_ver=$Net::FullAuto::VERSION;
+print "FAVER=$fa_ver\n";
    ($stdout,$stderr)=$handle->cmd(
-      "ls -1t $stdout | grep Net-FullAuto-$fa_ver");
+      "ls -1t $builddir | grep Net-FullAuto-$fa_ver");
    my @lstmp=split /\n/,$stdout;
    my @ls_tmp=();
    foreach my $line (@lstmp) {
